@@ -50,7 +50,7 @@ extern void SendRollbackRemote(const char *txnid, bool xa_end, bool written_only
 extern void SendRollbackSubToRemote(const char *name);
 extern bool Send1stPhaseRemote(const char *txnid, List **prepared_shards);
 extern void Send2ndPhaseRemote(const char *txnid);
-extern void StartTxnRemote(StringInfo cmd);
-extern char *MakeTopTxnName(TransactionId txnid, time_t now);
+extern void StartTxnRemote(StringInfo cmd, bool force_snapshot);
+extern char *MakeTopTxnName(int64_t txnid, time_t now);
 extern void insert_debug_sync(int where, int what, int which);
 #endif // !REMOTE_XACT_H
