@@ -36,29 +36,45 @@
  * */
 CATALOG(pg_shard_node,12345,ShardNodeRelationId) BKI_SHARED_RELATION BKI_WITHOUT_OIDS
 {
-  Oid id; /* shard node id. */
-  int32 port;
-  Oid shard_id; /* The owner shard, references pg_shard(oid). BKI can't specify
-				   foreign key though. */
-  Oid svr_node_id;
-  /*
-   * When dispatching read only select stmts to a slave, choose the one with
-   * max ro_weight of a shard. set it to 0 to disable slave reading to the node.
-   */
-  int16 ro_weight;
-  int16 ping; /* The ping latency from current CN */
-  int16 latency; /* The binlog sync latency from master */
-  NameData user_name;
-#ifdef CATALOG_VARLEN
-  /* host address , ipv6 or ipv4, or host name/domain name, denoted by addrtype. */
-  text hostaddr;
-  text passwd BKI_FORCE_NOT_NULL;
-  timestamptz when_created BKI_DEFAULT(0);
-  json extra; /* extra information added in the future*/
+	Oid id; /* shard node id. */
+	int32 port;
+	Oid shard_id; /* The owner shard, references pg_shard(oid). BKI can't specify foreign key though. */
+	Oid svr_node_id;
+	/*
+	 * When dispatching read only select stmts to a slave, choose the one with
+	 * max ro_weight of a shard. set it to 0 to disable slave reading to the node.
+	 */
+	int16 ro_weight;
 
+	/* The ping latency from current CN */
+	int16 ping;
+
+	/* The binlog sync latency from master */
+	int16 latency;
+	NameData user_name;
+#ifdef CATALOG_VARLEN
+	/* host address , ipv6 or ipv4, or host name/domain name, denoted by addrtype. */
+	text hostaddr;
+	text passwd BKI_FORCE_NOT_NULL;
+	timestamptz when_created BKI_DEFAULT(0);
+	/* extra information that can be added in the future*/
+	json extra;
 #endif
-} FormData_pg_shard_node;
+}
+FormData_pg_shard_node;
 
 typedef FormData_pg_shard_node* Form_pg_shard_node;
 
+extern void pg_shard_node_add_one(Oid shardid,
+				   Oid nodeid,
+				   Oid svr_node_id,
+				   Datum hostaddr,
+				   int32 port,
+				   NameData *user,
+				   Datum passwd,
+				   int16 ro_weight,
+				   Datum create_tz);
+
+extern void pg_shard_node_del_one(Oid nodeid);
+
 #endif /* !PG_SHARD_NODE_H */
