@@ -64,7 +64,9 @@
 #define EXEC_FLAG_WITHOUT_OIDS	0x0040	/* force no OIDs in returned tuples */
 #define EXEC_FLAG_WITH_NO_DATA	0x0080	/* rel scannability doesn't matter */
 #define EXEC_FLAG_REMOTE_FETCH_NO_DATA	0x0100	/* do not prepare/try to fetch remote data, only create relevant nodes/objects */
-
+#define EXEC_FLAG_REMOTE_BINARY_PROTOCOL 0x0200 /* prefer mysql binary protocal when execute remote sql*/
+#define EXEC_FLAG_DISABLE_REMOTE_PARALLEL 0x0400 /* prefer parallel connection */
+#define EXEC_FLAG_TOP_QUERY 0x0800 	/* indicate the plan is top most query */
 
 /* Hook for plugins to get control in ExecutorStart() */
 typedef void (*ExecutorStart_hook_type) (QueryDesc *queryDesc, int eflags);
@@ -232,6 +234,9 @@ extern void ExecEndNode(PlanState *node);
 extern bool ExecShutdownNode(PlanState *node);
 extern void ExecSetTupleBound(int64 tuples_needed, PlanState *child_node);
 
+extern int EstimateRemoteInteractions(EState *estate, Plan *node);
+extern void ExecOptimizePlanStateAfterwards(PlanState *planstate);
+
 
 /* ----------------------------------------------------------------
  *		ExecProcNode
