@@ -31,7 +31,8 @@
 #include "utils/algos.h"
 #include "nodes/tidbitmap.h"
 #include "storage/condition_variable.h"
-#include "sharding/sharding_conn.h"
+//#include "sharding/sharding_conn.h"
+#include "sharding/stmt_hdl.h"
 
 
 struct PlanState;				/* forward references in this file */
@@ -40,7 +41,6 @@ struct ExprState;
 struct ExprContext;
 struct ExprEvalStep;			/* avoid including execExpr.h everywhere */
 
-
 struct EnumLabelOid;
 typedef struct TypeInputInfo
 {
@@ -400,7 +400,7 @@ typedef struct OnConflictSetState
 
 
 struct RemotetupCacheState;
-
+struct RemoteModifyTupleCommon;
 /*
  * ResultRelInfo
  *
@@ -495,6 +495,12 @@ typedef struct ResultRelInfo
 	 * Memory should be alloc'ed from EState::es_query_cxt.
 	 * */
 	struct RemotetupCacheState *ri_RemotetupCache;
+
+	/*
+	 * Used for un-pushdownable update/delete statements to construct
+	 * sqls to update/delete tuples one by one.
+	 */
+	struct RemoteModifyTupleCommon *ri_RemoteModifyTupleCommon;
 } ResultRelInfo;
 
 
@@ -504,6 +510,9 @@ typedef struct ResultRelInfo
  * Master working state for an Executor invocation
  * ----------------
  */
+#define REPLICA_READ_NONE	0
+#define REPLICA_READ_FALSE	-1
+#define REPLICA_READ_TRUE	1
 typedef struct EState
 {
 	NodeTag		type;
@@ -610,6 +619,9 @@ typedef struct EState
 	int			es_jit_flags;
 	struct JitContext *es_jit;
 	struct JitInstrumentation *es_jit_worker_instr;
+	
+	/* Strategy of replica read */
+	int es_replica_read;
 } EState;
 
 
@@ -1069,14 +1081,16 @@ typedef struct ProjectSetState
 	MemoryContext argcontext;	/* context for SRF arguments */
 } ProjectSetState;
 
+struct AsyncStmtInfo;
 typedef struct RemoteModifyState
 {
-	AsyncStmtInfo *asi;         /* communication channel with storage node. */
+	struct AsyncStmtInfo *asi;         /* communication channel with storage node. */
 	StringInfoData remote_dml;
 	StmtSafeHandle handle;
 } RemoteModifyState;
 
 struct RemoteUD;
+struct RemoteUDPushdownState;
 /* ----------------
  *	 ModifyTableState information
  * ----------------
@@ -1099,17 +1113,6 @@ typedef struct ModifyTableState
 	ResultRelInfo *rootResultRelInfo; /* root target relation (partitioned
 									   * table root) */
 
-	bool is_pushdown_updel;	   /* true if this query is pushdownable delete/update */
-	List *pushdown_returning;  /* the returning clause of the pushdownable delete/update */
-	struct RemoteUD *remote_updel; /* printer generating pushed delete/update*/
-	StmtSafeHandle *active_stmts;	   /* active stmts array */
-	int max_actieve_stmts;
-	int nactive_stmts;
-
-	TupleTableSlot *remoteReturningTupleSlot;
-	TypeInputInfo *typeInputInfo;
-	int cur_returning_idx;
-
 	List **mt_arowmarks;		  /* per-subplan ExecAuxRowMark lists */
 	EPQState mt_epqstate;		  /* for evaluating EvalPlanQual rechecks */
 	TupleTableSlot *mt_existing;  /* slot to store existing target tuple in */
@@ -1131,6 +1134,15 @@ typedef struct ModifyTableState
 	/* cached tuple conversion map to accelerate tupconv_map_for_partition()*/
 	int mt_current_partidx;
 
+	/* Fields used to dedup subplan tuples to avoid “halloween problem” */
+	bool mt_need_dedup;
+	bool mt_dedup_done;
+	ExprState *mt_tuplestore_eqfunc;
+	TupleTableSlot *mt_tuplestore_result;
+	Tuplesortstate *mt_tuplestore;
+
+	/* Fields used to pushdown update/delete direct ot shard nodes */
+	struct RemoteUDPushdownState *remote_state;
 } ModifyTableState;
 
 /* ----------------
@@ -1265,67 +1277,54 @@ typedef struct ScanState
 	TupleTableSlot *ss_ScanTupleSlot;
 } ScanState;
 
+struct SortColRef;
 
-typedef struct RemoteScanState
+/*
+ * The table name conflict when generating remote sql
+ */
+struct RangeTblEntry;
+typedef struct TableNameConflict
+{
+	int relid;
+	char *name;			/* The orignal name of the conflict table */
+	char *newName;		/* The modified name of the conflict table */
+	struct RangeTblEntry *rte;
+} TableNameConflict;
+
+typedef struct RemotePlanState
 {
 	ScanState	ss;				/* its first field is NodeTag */
+	CommandId cid;
+	/* The target shard id*/
+	Oid shardid;
+	/* The prepared remote sql */
 	StringInfoData remote_sql;
-	AsyncStmtInfo *asi;         /* communication channel with storage node. */
+	StringInfoData sql_param_digest;
+	/* The scanlist of remote sql */
+	List *scanlist;
+	 /* communication channel with storage node. */
+	struct AsyncStmtInfo *asi;
 	StmtSafeHandle handle;
 	TypeInputInfo *typeInputInfo;
-	/*
-	 * Attr Nums in this set is a 'long expression', i.e. longer than NAMEDATALEN.
-	 * Suppose the i'th 1 bit in long_exprs_bmp denotes number x, then the
-	 * tupdesc->attrs[x].attname doesn't contail complete expr text, need to use
-	 * long_exprs[i] instead.
-	 * */
-	Bitmapset *long_exprs_bmp;
-	List *long_exprs;
-
-	/*
-	 * The TupleDesc in ss.ps.scandesc may be allocated with more
-	 * FormData_pg_attribute slots than ss.ps.scandesc->natts, this field
-	 * stores the real capacity of ss.ps.scandesc->attrs array, in order to
-	 * store extra attrs for quals.
-	 * */
-	int scandesc_natts_cap;
-	bool fetches_remote_data;
-
-	/* when this is in a correlated subquery, do we use dependent outer param
-	   values to fetch each portion of qualified rows on each rescan, or do we fetch
-	   all rows that match quals containing no dependent params all at once.
-	   It's generally faster and less costly to do it the 2nd way, unless there
-	   are too many qualified rows.
-	   */
+	/* true if the channel use mysql binary protocol */
+	bool binary_protocol;
+	bool use_cursor;
+	MysqlDeserializeInfo *de;
+	/**
+	 * when this is in a correlated subquery, do we use dependent outer param
+	 * values to fetch each portion of qualified rows on each rescan, or do we fetch
+	 * all rows that match quals containing no dependent params all at once.
+	 * It's generally faster and less costly to do it the 2nd way, unless there
+	 * are too many qualified rows.
+	 */
 	bool		param_driven;
 
 	/*
-	   results of this remote scan is used for EXISTS() checks thus only 1 row
-	   needs to be returned.
-	   */
-	bool		check_exists;
-
-	/*
-	   need to rewind, most likely its resultset is used as inner node result
-	   of a join. If so store result rather than use result.
-	   */
+	  need to rewind, most likely its resultset is used as inner node result
+	  of a join. If so store result rather than use result.
+	*/
 	bool will_rewind;
-
-	/* Unpushable target list */
-	List *unpushable_tl;
-
-	/* Generated vars of scantuple, and the coresponding exprs */
-	List *scanvars;
-	List *scanexprs;
-
-	/* Origial plan->qual */
-	List *orignal_qual;
-
-	/* Quals pushdown to the storage */
-	List *quals_pushdown;
-	List *having_pushdown;
-
-} RemoteScanState;
+} RemotePlanState;
 
 /* ----------------
  *	 SeqScanState information
@@ -1988,6 +1987,7 @@ typedef struct SortState
 	int64		bound_Done;		/* value of bound we did the sort with */
 	void	   *tuplesortstate; /* private state of tuplesort.c */
 	SharedSortInfo *shared_info;	/* one entry per worker */
+	bool		bypass;
 } SortState;
 
 /* ---------------------
