@@ -68,7 +68,8 @@ typedef enum NodeTag
 	T_WorkTableScan,
 	T_ForeignScan,
 	T_CustomScan,
-	T_RemoteScan,
+	T_RemotePath,
+	T_RemotePlan,
 	T_Join,
 	T_NestLoop,
 	T_MergeJoin,
@@ -125,7 +126,6 @@ typedef enum NodeTag
 	T_WorkTableScanState,
 	T_ForeignScanState,
 	T_CustomScanState,
-	T_RemoteScanState,
 	T_JoinState,
 	T_NestLoopState,
 	T_MergeJoinState,
@@ -142,6 +142,7 @@ typedef enum NodeTag
 	T_SetOpState,
 	T_LockRowsState,
 	T_LimitState,
+	T_RemotePlanState,
 
 	/*
 	 * TAGS FOR PRIMITIVE NODES (primnodes.h)
@@ -421,6 +422,22 @@ typedef enum NodeTag
 	T_CreateStatsStmt,
 	T_AlterCollationStmt,
 	T_CallStmt,
+	T_UseStmt,
+	T_ShowDiagnoStmt,
+	T_KillStmt,
+	T_ShowDatabasesStmt,
+	T_ShowSchemasStmt,
+	T_ShowTablesStmt,
+	T_ShowTableStatusStmt,
+	T_ShowCreateTableStmt,
+	T_ShowProcessListStmt,
+	T_SendShardStmt,
+	T_FetchMySQLVarStmt,
+	T_MySQLVarRef,
+	T_ShowCollationStmt,
+	T_ShowCharsetStmt,
+	T_MultiVariableSetStmt,
+    T_ShowMemoryStmt,
 
 	/*
 	 * TAGS FOR PARSE TREE NODES (parsenodes.h)
@@ -438,6 +455,7 @@ typedef enum NodeTag
 	T_MultiAssignRef,
 	T_TypeCast,
 	T_CollateClause,
+	T_OnUpdateTimeClause,
 	T_SortBy,
 	T_WindowDef,
 	T_RangeSubselect,
@@ -667,7 +685,7 @@ typedef enum CmdType
 								 * etc. */
 	/* 
 	 * dzw:
-	 * CMD_DDL and CMD_TXN_MGMT are only used by my code, not by official pg.
+	 * CMD_DDL and CMD_TXN_MGMT are only used by kunlun-server code, not by official pg.
 	 * The 2 categories of cmds are seen as CMD_UTILITY by pg.
 	 * */
 	CMD_DDL,                    /* create/drop/alter db/table, etc */
