@@ -20,7 +20,7 @@
 #include "nodes/bitmapset.h"
 #include "nodes/lockoptions.h"
 #include "nodes/primnodes.h"
-
+#include "nodes/relation.h"
 
 /* ----------------------------------------------------------------
  *						node definitions
@@ -95,7 +95,7 @@ typedef struct PlannedStmt
 	List	   *paramExecTypes; /* type OIDs for PARAM_EXEC Params */
 
 	Node	   *utilityStmt;	/* non-null if this is utility stmt */
-
+	
 	/* statement location in source string (copied from Query) */
 	int			stmt_location;	/* start location, or -1 if unknown */
 	int			stmt_len;		/* length in bytes; 0 means "rest of string" */
@@ -216,6 +216,7 @@ typedef struct ProjectSet
 	Plan		plan;
 } ProjectSet;
 
+struct RemoteUDPushdown;
 /* ----------------
  *	 ModifyTable node -
  *		Apply rows produced by subplan(s) to result table(s),
@@ -250,6 +251,13 @@ typedef struct ModifyTable
 	Node	   *onConflictWhere;	/* WHERE for ON CONFLICT UPDATE */
 	Index		exclRelRTI;		/* RTI of the EXCLUDED pseudo relation */
 	List	   *exclRelTlist;	/* tlist of the EXCLUDED pseudo relation */
+	/* Attribute mapping of planSlot to result relation,
+	    avoiding extra fetch when constructing returning clause
+	    */
+	List	*resultRelationAttrMap;
+
+	/* Pushed down remote stmts */
+	struct RemoteUDPushdown *remotePushdown;
 } ModifyTable;
 
 struct PartitionPruneInfo;		/* forward reference to struct below */
@@ -360,11 +368,21 @@ typedef struct RemoteScan
 	with 1st column of the target table, though we could modify the targetlist
 	to contain a single boolean column. */
 	bool		check_exists;
+
 	/*
 	  True iff this node has a Material parent. This is to prevent multiple
 	  Materialization to the same RS node when it's referenced by multiple places.
+	  e.g. a SubPlan referenced in a ProjectionInfo exprstate but not in the
+	  targetlist.
 	*/
 	bool		materialized;
+
+	/*
+	  Set to true if we want to sort the pushed down agg grouped rows so we
+	  can do a quick merge in computing nodes.
+	*/
+	bool	sort_groups;
+
 	/*
 	 * TODO:
 	 * we don't need to decide for storage node which index to use to fetch
@@ -385,6 +403,37 @@ typedef struct RemoteScan
 	List	   *indexorderbyops;
 	ScanDirection indexorderdir;
 	 * */
+
+	/*
+	  If not NULL, a list of exprs representing the grouping exprs.
+	  All of it must be able to push down, and this has been checked already
+	  during planning.
+	*/
+	List *grouping_exprs;
+	/*
+	  If not NULL, a list of exprs representing the having clause quals.
+	  During planning these are all having quals of a remote pushed down agg.
+	  During execution these are having quals that have to be kept in computing
+	  node, and there may be more having quals which are pushed down.
+
+	  It's OK if some or none of it can be pushed down, we can simply
+	  use them as row filters to filter unqualified agg rows in computing
+	  node.
+	*/
+	List *havingQuals;
+
+
+	/*
+	 Saved target list before set_plan_refs(), we need this to find out the source of
+	 PlaceHolderVar used by the upper level RemoteJoin when generating remote sql
+	 */
+	List *targetList;
+
+	/* PlaceHolderVars generated in current scan or join */
+	List *generatedPhvs;
+
+	/* PlaceHolderVars generated by scans or joins below */
+	List *referencedPhvs;
 } RemoteScan;
 
 typedef struct Scan
@@ -780,6 +829,68 @@ typedef struct MergeJoin
 	bool	   *mergeNullsFirst;	/* per-clause nulls ordering */
 } MergeJoin;
 
+
+/*
+  dzw: push down Joins whose left and right RS node is on the same shard.
+  And this can be extended to push down a subtree with more RS/RJ/RSO nodes
+  that are on the same shard.
+  For such a subtree we simply produce one RJ node, which we produce SQL as
+  if doing a mid-order tree traverse. And we use rj_plans to refer to such
+  plan nodes, and the RJ.join.plan.left/right_tree are not used.
+  We use parse tree to produce RJPath nodes which are then used to produce the
+  RJ subtree, so we can avoid optimization for the subtrees
+  that can be totally pushed down.
+  OLD push down can be done to an RJ/RSO node just the same as done to an RS
+  node. materialization handles an RJ/RSO just the same as an RS node.
+
+  RemoteJoin isn't a Join node in computing node perspective, it's a special
+  remotescan targeting a specific shard and involving multiple tables doing
+  join on the target shard.
+*/
+typedef struct RemoteJoin
+{
+	RemoteScan	remote_scan;
+	JoinType	jointype;
+	bool		inner_unique;
+	List	   *joinqual;		/* JOIN quals (in addition to plan.qual) */
+	Oid			rj_shardid;
+} RemoteJoin;
+
+typedef struct RemtePlan
+{
+	Plan plan;
+	/* The target shard */
+	Oid shard;
+	
+	Relids relids;
+	/* List of parent rt index of relids*/
+	List *parent_relids;
+	
+	/* The geneated prepared sql*/
+	const char *prepared_sql;
+
+	/* Fields needed by update/delete to construct the update/delete query */
+	List *topwhere;
+	List *sortexpr;
+	List *sortop;
+	List *sortnullfirst;
+	Node *limitoff;
+	Node *limitcnt;
+
+	/* The parameters refered in prepared_sql*/
+	List *params;
+	List *param_locations;
+	/* The target list of the prepared_sql */
+	List *scan_list;
+
+	/* The orignal target list, saved for explain */
+	List *original_target_list;
+
+	/* if the sql or quals contain volatile functions */
+	bool has_volatile;
+	bool disable_parallel;
+	bool contain_lock;
+} RemotePlan;
 /* ----------------
  *		hash join node
  * ----------------
@@ -797,11 +908,6 @@ typedef struct HashJoin
 typedef struct Material
 {
 	Plan		plan;
-
-	/*
-  	  dzw: fetch all rows at once in ExecInitMaterial()/rescan for remote table.
-	*/
-	bool		remote_fetch_all;
 } Material;
 
 /* ----------------
@@ -975,6 +1081,7 @@ typedef struct SetOp
 	long		numGroups;		/* estimated number of groups in input */
 } SetOp;
 
+
 /* ----------------
  *		lock-rows node
  *
@@ -1043,7 +1150,8 @@ typedef enum RowMarkType
 	ROW_MARK_SHARE,				/* obtain shared tuple lock */
 	ROW_MARK_KEYSHARE,			/* obtain keyshare tuple lock */
 	ROW_MARK_REFERENCE,			/* just fetch the TID, don't lock it */
-	ROW_MARK_COPY				/* physically copy the row value */
+	ROW_MARK_COPY,				/* physically copy the row value */
+	ROW_MARK_NONE                      /* lock tuple while fetch and never to epq on it */
 } RowMarkType;
 
 #define RowMarkRequiresRowShareLock(marktype)  ((marktype) <= ROW_MARK_KEYSHARE)
