@@ -19,6 +19,24 @@
 #include "nodes/params.h"
 
 #define nodeDisplay(x)		pprint(x)
+
+/*
+ * Print the PlaceHolderVar with newly generated alias if it is just a reference
+ */
+struct PlaceHolderVar;
+typedef struct PhvAlias
+{
+	struct PlaceHolderVar *phv;
+	char *alias;
+} PhvAlias;
+
+typedef struct VarAlias
+{
+	Var *var;
+	char *alias;
+	int levelno;
+} VarAlias;
+
 typedef struct RemotePrintExprContext
 {
 	EState *estate;
@@ -29,12 +47,29 @@ typedef struct RemotePrintExprContext
 	ParamExecData *rpec_param_exec_vals;
 	ParamListInfo rpec_param_list_info;
 
+	/* True if print param/unsafe func as '?' */
+	bool make_prepare_stmt;
+	bool parameterized_const_expr;
+	/* Information abort the param (i.e. position in sql)*/
+	List *params;
+	List *params_location;
+	/* Information abort the unsafe function */
+	List *unsafe_func_placeholder;
+
 	/*
-	 * If true, param node will be executed if it does not refer to
-	 * external parameters, otherwise it will be treated unsupported
-	 */
+	  If true, param node will be executed if it does not refer to
+	  external parameters, otherwise it will be treated unsupported
+	*/
 	bool exec_param_quals;
-	int num_vals;
+
+	/* Placeholder vars that assigned aliases */
+	List *phv_alias;
+
+	/* Vars that assigned aliases */
+	List *var_alias;
+
+	/* Print var with relname, i.e. t1.a */
+	bool full_varname;
 
 	/* Column name of excluded table in on conflict clause */
 	List *excluded_table_columns;
@@ -47,6 +82,7 @@ typedef struct RemotePrintExprContext
 } RemotePrintExprContext;
 
 extern void InitRemotePrintExprContext(RemotePrintExprContext *rpec, List*rtable);
+extern void ResetRemotePrintExprContext(RemotePrintExprContext *rpec, bool b);
 extern void print(const void *obj);
 extern void pprint(const void *obj);
 extern void elog_node_display(int lev, const char *title,
@@ -58,6 +94,11 @@ extern void print_expr(const Node *expr, const List *rtable);
 extern void print_pathkeys(const List *pathkeys, const List *rtable);
 extern void print_tl(const List *tlist, const List *rtable);
 extern void print_slot(TupleTableSlot *slot);
+
+extern bool is_mysql_proc(Oid funcoid);
+extern bool is_mysql_operator(Oid opoid);
+extern bool is_expr_printable(const Expr *expr, RemotePrintExprContext *rpec);
 extern int snprint_expr(StringInfo buf, const Expr *expr, RemotePrintExprContext *rpec);
 extern Oid my_output_funcoid(Oid typid, bool *typIsVarlena);
+extern bool can_bind_param_expr(EState *estate, List *params);
 #endif							/* PRINT_H */
