@@ -371,10 +371,11 @@ extern char *GetConfigOptionByName(const char *name, const char **varname,
 					  bool missing_ok);
 extern void GetConfigOptionByNum(int varnum, const char **values, bool *noshow);
 extern int	GetNumConfigOptions(void);
+extern void SetConfig(bool resetall, char *name, char *value);
 
 extern void SetPGVariable(const char *name, List *args, bool is_local);
 extern void GetPGVariable(VariableShowStmt *n, DestReceiver *dest);
-extern void GetVariablesShard(VariableShowStmt *n, DestReceiver *dest);
+extern void GetVariablesShard(VariableShowStmt *n, const char *queryString, DestReceiver *dest);
 
 extern TupleDesc GetPGVariableResultDesc(VariableShowStmt *n);
 
@@ -437,6 +438,9 @@ extern void assign_search_path(const char *newval, void *extra);
 extern bool check_wal_buffers(int *newval, void **extra, GucSource source);
 extern void assign_xlog_sync_method(int new_sync_method, void *extra);
 
+extern const char *current_authorization(void);
+extern const char *current_role(void);
 extern const char *current_search_path(void);
-extern const char *set_search_path(const char *path);
+extern const char* set_search_path(const char *path);
+
 #endif							/* GUC_H */
