@@ -64,6 +64,8 @@ def add_computing_nodes(mysql_conn_params, args, config_path, install_ids, intoS
         ha_mode = 0
     elif row[2] == 'mgr':
         ha_mode = 1
+    elif row[2] == 'rbr':
+        ha_mode = 2
 
     meta_cursor.execute('select value from global_configuration where name=%s', ('meta_ha_mode',))
     row = meta_cursor.fetchone()
@@ -75,15 +77,24 @@ def add_computing_nodes(mysql_conn_params, args, config_path, install_ids, intoS
     elif row[0] == 'rbr':
         meta_ha_mode = 2
 
+    meta_cursor.execute("select id, hostaddr from server_nodes where machine_type='computer'")
+    server_rows = meta_cursor.fetchall()
+    idmap = {}
+    for server_row in server_rows:
+        idmap[bytes(server_row[1])] = server_row[0]
+
     meta_cursor0 = meta_conn.cursor(buffered=True, dictionary=True)
 
     # insert computing nodes info into meta-tables.
-    stmt = "insert into comp_nodes(id, name, hostaddr, port, db_cluster_id,user_name,passwd, svr_node_id) values(%s, %s, %s, %s, %s, %s, %s, 1)"
+    stmt = "insert into comp_nodes(id, name, hostaddr, port, mysql_port, db_cluster_id,user_name,passwd, svr_node_id) values(%s, %s, %s, %s, %s, %s, %s, %s, %s)"
     idstmt = "insert into comp_nodes_id_seq(id) values(%s)"
     meta_cursor0.execute("start transaction")
 
     for compcfg in jscfg:
-        meta_cursor.execute(stmt, (compcfg['id'], compcfg['name'],compcfg['ip'], compcfg['port'], cluster_id, compcfg['user'], compcfg['password']))
+        svr_node_id = 1
+        if compcfg['ip'] in idmap:
+            svr_node_id = idmap[compcfg['ip']]
+        meta_cursor.execute(stmt, (compcfg['id'], compcfg['name'],compcfg['ip'], compcfg['port'], compcfg['mysql_port'], cluster_id, compcfg['user'], compcfg['password'], svr_node_id))
         if intoSeqTable:
             meta_cursor.execute(idstmt % str(compcfg['id']))
     meta_cursor.close()
@@ -105,7 +116,7 @@ def add_computing_nodes(mysql_conn_params, args, config_path, install_ids, intoS
 
     # insert meta data into each computing node's catalog tables.
     for compcfg in jscfg:
-        conn = psycopg2.connect(host=compcfg['ip'], port=compcfg['port'], user=compcfg['user'], database='postgres', password=compcfg['password'])
+        conn = psycopg2.connect(host=compcfg['ip'], port=compcfg['port'], user=compcfg['user'], database='postgres', password=compcfg['password'], application_name='kunlun_proc')
         cur = conn.cursor()
         cur.execute("set skip_tidsync = true; start transaction")
         cur.execute("insert into pg_cluster_meta values(%s, %s, %s, %s, %s, %s, %s)",
@@ -140,7 +151,7 @@ def add_computing_nodes(mysql_conn_params, args, config_path, install_ids, intoS
                 continue
             shard_nrows[shard_node_row['shard_id']] += 1;
             cur.execute("insert into pg_shard_node values(%s, %s, %s, %s, %s, %s, %s, %s, %s, %s, %s)",
-                    (shard_node_row['id'], shard_node_row['port'], shard_node_row['shard_id'], 0, 0, 0, 0,
+                    (shard_node_row['id'], shard_node_row['port'], shard_node_row['shard_id'], shard_node_row['svr_node_id'], shard_node_row['ro_weight'], 0, 0,
                      shard_node_row['user_name'], shard_node_row['hostaddr'], shard_node_row['passwd'], shard_node_row['when_created']))
             # update master_node_id to any node's id of the shard, it can't be 0 otherwise computing node won't be able to work.
             cur.execute("update pg_shard set master_node_id = %s where master_node_id = 0 and id=%s", (shard_node_row['id'], shard_node_row['shard_id']))
@@ -169,7 +180,7 @@ if __name__ == '__main__':
     parser.add_argument('--meta_config', type=str, help="metadata cluster config file path")
     parser.add_argument('--cluster_name', type=str)
     parser.add_argument('--targets', type=str, help="target computing nodes to install. e.g. all, or 1,2,3")
-    parser.add_argument('--ha_mode', type=str, default='mgr', choices=['mgr','no_rep'])
+    parser.add_argument('--ha_mode', type=str, default='rbr', choices=['mgr','no_rep', 'rbr'])
 
     args = parser.parse_args()
     install_ids = []
