@@ -48,10 +48,16 @@ def add_shards_to_cluster(mysql_conn_params, cluster_name, config_path, install_
     row = meta_cursor.fetchone()
     cluster_id = row[0]
 
+    meta_cursor.execute("select id, hostaddr from server_nodes where machine_type='storage'")
+    server_rows = meta_cursor.fetchall()
+    idmap = {}
+    for server_row in server_rows:
+        idmap[bytes(server_row[1])] = server_row[0]
+
     num_nodes = 0
 
     add_shard_stmt = "insert into shards(name, when_created, num_nodes, db_cluster_id) values(%s, now(), 0, %s)"
-    add_shard_node_stmt = "insert into shard_nodes(hostaddr, port, user_name, passwd, shard_id, db_cluster_id, svr_node_id, master_priority) values(%s, %s, %s, %s, %s, %s, 1,0)"
+    add_shard_node_stmt = "insert into shard_nodes(ro_weight, hostaddr, port, user_name, passwd, shard_id, db_cluster_id, svr_node_id, master_priority) values(%s, %s, %s, %s, %s, %s, %s, %s, %s)"
 
     jscfg = []
     nshards = 0
@@ -92,7 +98,22 @@ def add_shards_to_cluster(mysql_conn_params, cluster_name, config_path, install_
         shardcfg['shard_id'] = shard_id
         num_nodes = 0
         for val in shardcfg['shard_nodes']:
-            meta_cursor.execute(add_shard_node_stmt, (val['ip'], val['port'], val['user'], val['password'], shard_id, cluster_id))
+            svr_node_id = 1
+            if val['ip'] in idmap:
+                svr_node_id = idmap[val['ip']]
+            val['svr_node_id'] = svr_node_id
+            ro_weight = 10
+            if 'ro_weight' in val:
+                ro_weight = val['ro_weight']
+            else:
+                val['ro_weight'] = ro_weight
+            master_priority = 10
+            if 'master_priority' in val:
+                master_priority = val['master_priority']
+            else:
+                val['master_priority'] = master_priority
+            meta_cursor.execute(add_shard_node_stmt, (val['ro_weight'], val['ip'], val['port'], val['user'], val['password'],
+                shard_id, cluster_id, val['svr_node_id'], val['master_priority']))
             meta_cursor0.execute("select last_insert_id() as id")
             row0 = meta_cursor0.fetchone()
             val['shard_node_id'] = row0['id']
@@ -109,7 +130,7 @@ def add_shards_to_cluster(mysql_conn_params, cluster_name, config_path, install_
     for master in masters:
         master_conn = mysql.connector.connect(**master)
         master_cursor = master_conn.cursor()
-        master_cursor.execute("create database postgres_$$_public CHARACTER set=utf8")
+        master_cursor.execute("create database postgres_$$_public")
         master_cursor.close()
         master_conn.close()
 
@@ -124,7 +145,7 @@ def add_new_shards_to_all_computing_nodes(cluster_id, meta_conn, jscfg):
     meta_cursor0.execute("select * from comp_nodes where db_cluster_id={}".format(cluster_id))
 
     for row in meta_cursor0:
-        conn = psycopg2.connect(host=row['hostaddr'], port=row['port'], user=row['user_name'], database='postgres', password=row['passwd'])
+        conn = psycopg2.connect(host=row['hostaddr'], port=row['port'], user=row['user_name'], database='postgres', password=row['passwd'], application_name='kunlun_proc')
         cur = conn.cursor()
         nretries = 0
         while nretries < 10:
@@ -135,7 +156,7 @@ def add_new_shards_to_all_computing_nodes(cluster_id, meta_conn, jscfg):
                             (shardcfg['shard_name'], shardcfg['shard_id'], shardcfg['num_nodes'], shardcfg['shard_nodes'][0]['shard_node_id'], 0, 0, cluster_id))
                     for v in shardcfg['shard_nodes']:
                         cur.execute("insert into pg_shard_node values(%s, %s, %s, %s, %s, %s, %s, %s, %s, %s, now())",
-                                (v['shard_node_id'], v['port'], shardcfg['shard_id'], 0, 0, 0, 0, v['user'], v['ip'], v['password']))
+                                (v['shard_node_id'], v['port'], shardcfg['shard_id'], v['svr_node_id'], v['ro_weight'], 0, 0, v['user'], v['ip'], v['password']))
                 cur.execute("commit")
                 break
             except psycopg2.Error as pgerr:
@@ -154,8 +175,8 @@ if __name__ == '__main__':
     parser.add_argument('--meta_config', type=str, help="metadata cluster config file path")
     parser.add_argument('--cluster_name', type=str)
     parser.add_argument('--targets', type=str, help="target shards to install, specified by shard names. If none, add all shards.")
-    parser.add_argument('--ha_mode', type=str, default='mgr', choices=['mgr','no_rep'])
-    parser.add_argument('--meta_ha_mode', type=str, default='mgr', choices=['mgr','no_rep'])
+    parser.add_argument('--ha_mode', type=str, default='rbr', choices=['mgr','no_rep', 'rbr'])
+    parser.add_argument('--meta_ha_mode', type=str, default='rbr', choices=['mgr','no_rep', 'rbr'])
 
     args = parser.parse_args()
     install_names = []
