@@ -50,45 +50,85 @@ def mysql_node_check_mgr(conn_params):
 	conn.close()
 	return row[0], row[1]
 
+def mysql_node_check_rbr(conn_params):
+    conn = connect_mysql(conn_params)
+    mysql_version_check(conn, conn_params)
+    csr=conn.cursor()
+    csr.execute("select HOST, PORT from performance_schema.replication_connection_configuration where channel_name='kunlun_repl'")
+    row = csr.fetchone()
+    csr.close()
+    if row == None or row[0] == None or row[0] == '' or row[1] == None:
+        csr=conn.cursor()
+        csr.execute("show slave hosts")
+        rows=csr.fetchall()
+        slavecnt = len(rows)
+        csr.close()
+        if slavecnt >= 1:
+            conn.close()
+            return conn_params['ip'], conn_params['port']
+        else:
+            raise Exception("ERROR: Node {} disconnected from its shard cluster.".format(str(conn_params)))
+    else:
+        csr.close()
+        conn.close()
+        return row[0], row[1]
+
 # make sure all nodes are in the same shard and has the same master node
 # return the master node params suitable for mysql connection
 def mysql_shard_check(shard_conn_params, ha_mode):
-	cur_prim_ip = ''
-	cur_prim_port = 0
-	prim_node = None
+    cur_prim_ip = ''
+    cur_prim_port = 0
+    prim_node = None
+    mastermap = {}
 
-	for node in shard_conn_params:
-		node['use_pure'] = True
-		if ha_mode == 'mgr':
-                    node_mip, node_mport = mysql_node_check_mgr(node)
-                else:
-                    node_mip, node_mport = mysql_node_check_norep(node)
-		if cur_prim_port == 0:
-			cur_prim_ip = node_mip
-			cur_prim_port = node_mport
-		elif cur_prim_ip != node_mip or cur_prim_port != node_mport:
-			raise Exception("Node {} has different primary node ({}:{}) than currently found primary node({}:{})".format(str(node), node_mip, node_mport, cur_prim_ip, cur_prim_port))
+    for node in shard_conn_params:
+        node['use_pure'] = True
+        if ha_mode == 'mgr':
+            node_mip, node_mport = mysql_node_check_mgr(node)
+        elif ha_mode == 'rbr':
+            node_mip, node_mport = mysql_node_check_rbr(node)
+        else:
+            node_mip, node_mport = mysql_node_check_norep(node)
+        mastermap[(node['ip'], node['port'])] = (node_mip, node_mport)
+    for node in shard_conn_params:
+        mkey = (node['ip'], node['port'])
+        while True:
+            if mkey not in mastermap:
+                raise Exception("ERROR: Node {} disconnected from its shard cluster.".format(str(node)))
+            mpair = mastermap[mkey]
+            # this is the real master.
+            if mkey[0] == mpair[0] and mkey[1] == mpair[1]:
+                break
+            # continue to check upper master.
+            mkey = mpair
+        if cur_prim_port == 0:
+            cur_prim_ip = mpair[0]
+            cur_prim_port = mpair[1]
+        elif cur_prim_ip != mpair[0] or cur_prim_port != mpair[1]:
+            raise Exception("Node {} has different primary node ({}:{}) than currently found primary node({}:{})".format(str(node),
+                mpair[0], mpair[1], cur_prim_ip, cur_prim_port))
 
-		if node['ip'] == cur_prim_ip and node['port'] == cur_prim_port:
-			prim_node = node
+        if node['ip'] == cur_prim_ip and node['port'] == cur_prim_port:
+            prim_node = node
 
-	if prim_node == None:
-		raise Exception("Shard primary node ({}:{}) is not found in the shard {}".format(cur_prim_ip, cur_prim_port, str(shard_conn_params)))
-	prim_node = copy.deepcopy(prim_node)
-	prim_node['host'] = prim_node['ip']
-	del prim_node['ip']
-        # delete invalid properties when connecting.
-        for attr in ['is_primary', 'data_dir_path', 'nodemgr_bin_path', 'ro_weight', 'master_priority']:
-            if attr in prim_node:
-                del prim_node[attr]
-	return prim_node
+    if prim_node == None:
+        raise Exception("Shard primary node ({}:{}) is not found in the shard {}".format(cur_prim_ip,
+            cur_prim_port, str(shard_conn_params)))
+    prim_node = copy.deepcopy(prim_node)
+    prim_node['host'] = prim_node['ip']
+    del prim_node['ip']
+    # delete invalid properties when connecting.
+    for attr in ['is_primary', 'data_dir_path', 'nodemgr_bin_path', 'ro_weight', 'master_priority']:
+        if attr in prim_node:
+            del prim_node[attr]
+    return prim_node
 
 if __name__ == '__main__':
 	parser = argparse.ArgumentParser(description='test functions in this file')
 	parser.add_argument('--config', help="shard config file path")
 	parser.add_argument('--meta_config', type=str, help="metadata cluster config file path")
-        parser.add_argument('--ha_mode', type=str, default='mgr', choices=['mgr','no_rep'])
-        parser.add_argument('--meta_ha_mode', type=str, default='mgr', choices=['mgr','no_rep'])
+        parser.add_argument('--ha_mode', type=str, default='mgr', choices=['mgr','no_rep', 'rbr'])
+        parser.add_argument('--meta_ha_mode', type=str, default='mgr', choices=['mgr','no_rep', 'rbr'])
 
 	args = parser.parse_args()
 
