@@ -42,7 +42,7 @@ def init_db(args):
   global localied_data_dir
   global localied_work_dir
   cmd0 = "export LD_LIBRARY_PATH=" + localied_work_dir + "/lib:$LD_LIBRARY_PATH;"
-  initcmd = cmd0 + localied_work_dir + '/bin/initdb -D ' + localied_data_dir
+  initcmd = cmd0 + localied_work_dir + '/bin/initdb -D ' + localied_data_dir + ' 2>&1'
   os.system(initcmd) 
 
 def deal_conf(args):
@@ -91,18 +91,18 @@ def boot_postgres(args):
   # add initial user for clients to use later.
   # TODO: use more restricted privs than superuser
   sql = "set skip_tidsync = true; CREATE USER agent PASSWORD 'agent_pwd' superuser; CREATE USER " + args.user + " PASSWORD '" + args.password + '\' superuser;'
-  psql_cmd = cmd0 + localied_work_dir + "/bin/psql -h localhost -p" + str(args.pg_protocal_port) + " -U " + getpass.getuser() + " -d postgres -c \"" + sql + "\""
+  psql_cmd = cmd0 + localied_work_dir + "/bin/psql -h {datadir} -p".format(datadir=localied_data_dir) + str(args.pg_protocal_port) + " -U " + getpass.getuser() + " -d postgres -c \"" + sql + "\""
   ret = os.system(psql_cmd)
   if ret != 0:
     sys.stderr.write("Kunlun-server instance initialization failed, please check the logfile {pglfp} for more information".format(pglfp=pg_logfp))
     sys.exit(1)
   # add mysql functions for mysql clients.
-  psql_cmd2 = cmd0 + localied_work_dir + "/bin/psql -h localhost -p" + str(args.pg_protocal_port) + " -U " + getpass.getuser() + " -d template1 -f " + localied_work_dir + "/scripts/mysql_funcs.sql"
+  psql_cmd2 = cmd0 + localied_work_dir + "/bin/psql -h {datadir} -p".format(datadir=localied_data_dir) + str(args.pg_protocal_port) + " -U " + getpass.getuser() + " -d template1 -f " + localied_work_dir + "/scripts/mysql_funcs.sql"
   ret = os.system(psql_cmd2)
   if ret != 0:
     sys.stderr.write("Kunlun-server instance initialization failed, please check the logfile {pglfp} for more information".format(pglfp=pg_logfp))
     sys.exit(1)
-  psql_cmd2 = cmd0 + localied_work_dir + "/bin/psql -h localhost -p" + str(args.pg_protocal_port) + " -U " + getpass.getuser() + " -d postgres -f " + localied_work_dir + "/scripts/mysql_funcs.sql"
+  psql_cmd2 = cmd0 + localied_work_dir + "/bin/psql -h {datadir} -p".format(datadir=localied_data_dir) + str(args.pg_protocal_port) + " -U " + getpass.getuser() + " -d postgres -f " + localied_work_dir + "/scripts/mysql_funcs.sql"
   ret = os.system(psql_cmd2)
   if ret != 0:
     sys.stderr.write("Kunlun-server instance initialization failed, please check the logfile {pglfp} for more information".format(pglfp=pg_logfp))
@@ -116,9 +116,6 @@ def boot_postgres(args):
   os.system("echo \"" + str(args.pg_protocal_port) + "==>" + localied_data_dir + "\" >> " + list_file)
 
 def rollBackInstallaiton(args):
-    global localied_conf_path
-    global localied_data_dir
-    global localied_work_dir
 
     error_count = 0
     workpath = "{prefix}/{pt}/{prgname}".format(
@@ -144,8 +141,10 @@ def rollBackInstallaiton(args):
 
     if os.path.isdir(install_err_log_pg) == False:
         os.makedirs(install_err_log_pg, 0o777)
-    pg_logfp = localied_data_dir + "/logfile-" + str(args.pg_protocal_port)
-    cmd_backup_log = "cp {pgl} {ielp}".format(pgl=pg_logfp,ielp=install_err_log_pg)
+    data_dir = "{dpr}/{pgport}".format(dpr=args.datadir_prefix,pgport=args.pg_protocal_port)
+    pg_logfp = data_dir + "/logfile-" + str(args.pg_protocal_port)
+    cmd_backup_log = "cp {pgl} {ielp}/".format(pgl=pg_logfp,ielp=install_err_log_pg)
+    #print(cmd_backup_log)
     try:
         os.system(cmd_backup_log)
     except OSError as err:
@@ -198,8 +197,9 @@ if __name__ == "__main__":
 
     # boot postgres
     boot_postgres(args)
-  except OSError as e:  
-    sys.stderr.write("Install postgres failed: {inf}".format(inf=str(e)))
+  except:  
+    rollBackInstallaiton(args)
+    sys.stderr.flush()
     sys.exit(1)
 
   sys.exit(0)
