@@ -27,7 +27,7 @@ def param_replace(string, rep_dict):
     pattern = re.compile("|".join([re.escape(k) for k in rep_dict.keys()]), re.M)
     return pattern.sub(lambda x: rep_dict[x.group(0)], string)
 
-def install_pg(config_template_file, install_path, compcfg):
+def install_pg(config_template_file, install_path, compcfg, valgrind):
     #check install datadir is empty, make it if not exist
     datadir = compcfg['datadir'].strip()
     if datadir[0] != '/':
@@ -38,11 +38,15 @@ def install_pg(config_template_file, install_path, compcfg):
         os.makedirs(datadir)
 
     portstr = str(compcfg['port'])
+    mysql_portstr = str(compcfg['mysql_port'])
     etc_path = install_path + "/etc"
     conf_list_file = etc_path+"/instances_list.txt"
     ret = os.system("grep '^" + portstr + "==>' " + conf_list_file + " >/dev/null 2>/dev/null")
     if ret == 0:
         raise Exception("Invalid port:" + portstr + ", The port is in use!")
+    ret = os.system("grep '^" + mysql_portstr + "==>' " + conf_list_file + " >/dev/null 2>/dev/null")
+    if ret == 0:
+        raise Exception("Invalid mysql port:" + mysql_portstr + ", The mysql port is in use!")
 
     # do initdb
     cmd0 = "export LD_LIBRARY_PATH=" + install_path + "/lib:$LD_LIBRARY_PATH;"
@@ -59,6 +63,7 @@ def install_pg(config_template_file, install_path, compcfg):
     config_template = open(conf_path, 'r').read()
     replace_items = {}
     replace_items['port_placeholder'] = portstr
+    replace_items['mysql_port_placeholder'] = mysql_portstr
     replace_items['comp_node_id_placeholder'] = str(compcfg['id'])
     replace_items['unix_socket_dir_place_holder'] = datadir
 
@@ -73,16 +78,25 @@ def install_pg(config_template_file, install_path, compcfg):
 
     # startup postgres, put log file in datadir too
     pg_logfp = datadir + "/logfile-" + str(compcfg['port'])
-    startup_cmd = cmd0 + cmd1 + install_path + '/bin/postgres -D ' + datadir + " > " + pg_logfp + " 2>&1 &"
+    prefix = ""
+    if valgrind:
+        prefix = "valgrind --leak-check=full --trace-children=yes --undef-value-errors=no "
+    startup_cmd = cmd0 + cmd1 + prefix + install_path + '/bin/postgres -D ' + datadir + " > " + pg_logfp + " 2>&1 &"
     os.system(startup_cmd)
     os.system('sleep 5'); # wait for postgres to startup
 
     # add initial user for clients to use later.
     # TODO: use more restricted privs than superuser
     sql = "set skip_tidsync = true; CREATE USER agent PASSWORD 'agent_pwd' superuser; CREATE USER " + compcfg['user'].strip() + " PASSWORD '" + compcfg['password'] + '\' superuser;'
-    psql_cmd = cmd0 + install_path + "/bin/psql -h localhost -p" + str(compcfg['port']) + " -U " + getpass.getuser() + " -d postgres -c \"" + sql + "\""
+    psql_cmd = cmd0 + install_path + "/bin/psql -h {dtr} -p".format(dtr=datadir) + str(compcfg['port']) + " -U " + getpass.getuser() + " -d postgres -c \"" + sql + "\""
     os.system(psql_cmd)
 
+	# add mysql functions for mysql clients.
+    psql_cmd2 =cmd0 +  install_path + "/bin/psql -h {dtr} -p".format(dtr=datadir) + str(compcfg['port']) + " -U " + getpass.getuser() + " -d template1 -f " + install_path + "/scripts/mysql_funcs.sql"
+    os.system(psql_cmd2)
+    psql_cmd2 = cmd0 + install_path + "/bin/psql -h {dtr} -p".format(dtr=datadir) + str(compcfg['port']) + " -U " + getpass.getuser() + " -d postgres -f " + install_path + "/scripts/mysql_funcs.sql"
+    os.system(psql_cmd2)
+
     # append the new instance's port to datadir mapping into instance_list.txt
     if not os.path.exists(etc_path):
         os.mkdir(etc_path)
@@ -93,6 +107,7 @@ if __name__ == "__main__":
     parser = argparse.ArgumentParser(description='Install the computing node.')
     parser.add_argument('--config', type=str, help="The config path", required=True)
     parser.add_argument('--install_ids', type=str, help = "The ids for the nodes to install", default='all')
+    parser.add_argument('--valgrind', help="whether to use valgrind", default=False, action='store_true')
     args = parser.parse_args()
     try:
         if args.install_ids != "all":
@@ -112,7 +127,7 @@ if __name__ == "__main__":
         idx = 0
         for compcfg in jscfg:
             if install_ids[0] == -1 or install_ids.count(compcfg['id']) > 0:
-                install_pg(config_template_file, install_path, compcfg)
+                install_pg(config_template_file, install_path, compcfg, args.valgrind)
                 print "Installation completed for instance in " + compcfg['datadir'].strip()
         print "Installation of computing nodes with ID(s) " + str(install_ids) + " in file " + args.config + " completed."
     except KeyError, e:
