@@ -130,6 +130,7 @@ CREATE TABLE `comp_nodes` (
   `name` varchar(64) NOT NULL,
   `hostaddr` varchar(8192) NOT NULL,
   `port` smallint unsigned NOT NULL,
+  `mysql_port` smallint unsigned NOT NULL,
   `db_cluster_id` int unsigned NOT NULL,
   `when_created` timestamp NULL DEFAULT (now()),
   `user_name` varchar(64) NOT NULL,
@@ -139,6 +140,7 @@ CREATE TABLE `comp_nodes` (
 
   -- resource limits, 0 means unlimited
   cpu_cores smallint unsigned NOT NULL default 0,
+  cpu_limit_mode enum('share','quota') DEFAULT 'share',
   max_mem_MB int unsigned NOT NULL default 0,
   max_conns int unsigned NOT NULL DEFAULT 0,
 
@@ -252,7 +254,6 @@ CREATE TABLE `server_nodes` (
   `used_port` text,
   `installing_port` text,
   PRIMARY KEY (`id`),
-  UNIQUE KEY `hostaddr_dcid_uniq` (`hostaddr`(512),`dc_id`),
   FOREIGN KEY (dc_id) references data_centers(id)
 ) ENGINE=InnoDB DEFAULT CHARSET=utf8;
 /*!40101 SET character_set_client = @saved_cs_client */;
@@ -338,6 +339,7 @@ CREATE TABLE `shard_nodes` (
 
   -- resource limits, 0 means unlimited
   cpu_cores smallint unsigned NOT NULL default 0,
+  cpu_limit_mode enum('share','quota') DEFAULT 'share',
   initial_storage_GB int unsigned NOT NULL default 0,
   max_storage_GB int unsigned NOT NULL default 0,
   innodb_buffer_pool_MB int unsigned NOT NULL default 0,
@@ -442,7 +444,7 @@ END ;
 create table backup_storage(
 	id int unsigned primary key auto_increment,
 	name varchar(256),
-	stype enum('HDFS', 'S3', 'EBS','CEPH', 'OTHER'), -- type of storage service
+	stype enum('HDFS', 'S3', 'EBS','CEPH','SSH','OTHER'), -- type of storage service
 	-- connection info
 	conn_str varchar(8192),
 	hostaddr varchar(8192),
@@ -546,6 +548,10 @@ create table table_move_jobs (
 	when_ended timestamp(6) NULL default null,
 	status varchar(128) not null default 'not_started', -- ('not_started', 'dumped', 'transmitted', 'loaded', 'caught_up', 'renamed', 'rerouted', 'done', 'failed'),
 	stage varchar(128) not null default 'not_started', -- ('not_started', 'dumped', 'transmitted', 'loaded', 'caught_up', 'renamed', 'rerouted', 'done', 'failed'),
+  binlog_gtid_before_reroute varchar(256) NULL default null,
+  binlog_idx_before_reroute varchar(256) NULL default null,
+  binlog_offset_before_reroute bigint unsigned NULL default null,
+  binlog_pos_before_reroute_timestamp timestamp(6) NULL default null,
 	-- extra info for expanding 
 	memo text default null
 ) ENGINE=InnoDB DEFAULT charset=utf8;
@@ -637,4 +643,90 @@ CREATE TABLE `cluster_shard_topology` (
   `timestamp` timestamp NULL DEFAULT CURRENT_TIMESTAMP,
   PRIMARY KEY (`id`)
 ) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4;
+
+DROP TABLE IF EXISTS `cluster_es_conf`;
+CREATE TABLE `cluster_es_conf` (
+  `id` int unsigned NOT NULL AUTO_INCREMENT,
+  `is_install` enum ('no','yes') DEFAULT 'no',
+  `es_hostaddr` varchar(8192) NOT NULL,
+  `es_port` int unsigned DEFAULT NULL,
+  PRIMARY KEY (`id`)
+) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4;
+
+DROP TABLE IF EXISTS `proxysql_nodes`;
+CREATE TABLE `proxysql_nodes` (
+  `id` int unsigned NOT NULL,
+  `name` varchar(64) NOT NULL,
+  `hostaddr` varchar(8192) NOT NULL,
+  `port` smallint unsigned NOT NULL,
+  `db_cluster_id` int unsigned NOT NULL,
+  `when_created` timestamp NULL DEFAULT (now()),
+  `user_name` varchar(64) NOT NULL,
+  `passwd` varchar(16) NOT NULL,
+  `status` enum('creating','inactive','active','deleted','manual_stop') DEFAULT 'creating',
+  `svr_node_id` int unsigned NOT NULL,
+  `cpu_cores` smallint unsigned NOT NULL DEFAULT '0',
+  `max_mem_MB` int unsigned NOT NULL DEFAULT '0',
+  `max_conns` int unsigned NOT NULL DEFAULT '0',
+  `extra_props` text,
+  PRIMARY KEY (`db_cluster_id`,`id`),
+  UNIQUE KEY `cluster_id_name` (`db_cluster_id`,`name`),
+  KEY `svr_node_id` (`svr_node_id`),
+  CONSTRAINT `proxysql_nodes_ibfk_1` FOREIGN KEY (`db_cluster_id`) REFERENCES `db_clusters` (`id`),
+  CONSTRAINT `proxysql_nodes_ibfk_2` FOREIGN KEY (`svr_node_id`) REFERENCES `server_nodes` (`id`)
+) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4;
+
+DROP TABLE IF EXISTS `cluster_logicalbackups`;
+CREATE TABLE `cluster_logicalbackups` (
+  `id` bigint unsigned NOT NULL AUTO_INCREMENT,
+  `cluster_id` int NOT NULL DEFAULT '0',
+  `db_table` varchar(1024) COLLATE utf8mb4_0900_as_cs DEFAULT '',
+  `backup_time` varchar(255) COLLATE utf8mb4_0900_as_cs DEFAULT '',
+  `status` enum('not_started','ongoing','done','failed') COLLATE utf8mb4_0900_as_cs NOT NULL DEFAULT 'not_started',
+  `backup_addr` varchar(1024) COLLATE utf8mb4_0900_as_cs DEFAULT NULL,
+  PRIMARY KEY (`id`)
+) ENGINE=InnoDB AUTO_INCREMENT=2 DEFAULT CHARSET=utf8mb4;
+
+DROP TABLE IF EXISTS `cluster_logicalbackup_record`;
+CREATE TABLE `cluster_logicalbackup_record` (
+  `id` bigint unsigned NOT NULL AUTO_INCREMENT,
+  `cluster_id` int NOT NULL DEFAULT '0',
+  `db_table` varchar(1024) CHARACTER SET utf8mb4 COLLATE utf8mb4_0900_as_cs DEFAULT '',
+  `execute_host` varchar(128) DEFAULT NULL,
+  `job_id` varchar(128) DEFAULT NULL,
+  `backup_time` timestamp NULL DEFAULT (now()),
+  `backup_state` enum('done','failed') CHARACTER SET utf8mb4 COLLATE utf8mb4_0900_as_cs NOT NULL DEFAULT 'failed',
+  `backup_info` text,
+  PRIMARY KEY (`id`)
+)ENGINE=InnoDB;
+
+DROP TABLE IF EXISTS `cluster_scheduler_jobs`;
+CREATE TABLE `cluster_scheduler_jobs` (
+  `id` bigint unsigned NOT NULL AUTO_INCREMENT,
+  `job_type` enum('del_table_repartition_src_table') DEFAULT NULL,
+  `exec_time` datetime DEFAULT NULL,
+  `status` enum('running','done','deleted') DEFAULT 'running',
+  `memo` text,
+  PRIMARY KEY (`id`)
+) ENGINE=InnoDB;
+
+DROP TABLE IF EXISTS `user_consumption`;
+CREATE TABLE `user_consumption` (
+  `id` int unsigned NOT NULL AUTO_INCREMENT,
+  `cluster_id` bigint unsigned NOT NULL,
+  `user_name` varchar(128) COLLATE utf8mb4_0900_as_cs NOT NULL,
+  `queries` bigint unsigned DEFAULT '0',
+  `txns_committed` bigint unsigned DEFAULT '0',
+  `txn_write_size` bigint unsigned DEFAULT '0',
+  `scanned_rows` bigint unsigned DEFAULT '0',
+  `write_rows` bigint unsigned DEFAULT '0',
+  `net_io` bigint unsigned DEFAULT '0',
+  `disk_space_MB` bigint unsigned DEFAULT '0',
+  `begin_time` datetime DEFAULT CURRENT_TIMESTAMP,
+  `end_time` datetime DEFAULT NULL,
+  `status` enum('open','frozen') COLLATE utf8mb4_0900_as_cs DEFAULT 'open',
+  `business_trade_id` varchar(255) COLLATE utf8mb4_0900_as_cs DEFAULT '',
+  PRIMARY KEY (`id`),
+  KEY `id_name` (`cluster_id`,`user_name`)
+) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4;
 -- Dump completed on 2020-01-04 11:14:45
