@@ -1119,6 +1119,13 @@ LANGUAGE INTERNAL
 STRICT IMMUTABLE PARALLEL SAFE
 AS 'jsonb_insert';
 
+CREATE OR REPLACE FUNCTION
+  now(scale int4 DEFAULT 6)
+RETURNS timestamptz
+LANGUAGE INTERNAL
+STRICT STABLE
+PARALLEL RESTRICTED
+AS 'now_scale';
 --
 -- The default permissions for functions mean that anyone can execute them.
 -- A number of functions shouldn't be executable by just anyone, but rather
